@@ -47,7 +47,7 @@ class Button(Observable):
         self.widget = gtk.Button(**args)
 
         readonly = bool(int(attrs.get('readonly', '0')))
-        self.widget.set_sensitive( not readonly )
+        self.set_sensitive(not readonly)
 
         if attrs.get('icon', False):
             try:
@@ -71,6 +71,9 @@ class Button(Observable):
     def show(self):
         return self.widget.show()
 
+    def set_sensitive(self, value):
+        return self.widget.set_sensitive(value)
+
     def button_clicked(self, widget):
         model = self.form.screen.current_model
         self.form.set_value()
@@ -131,6 +134,7 @@ class Button(Observable):
                     raise Exception, 'Unallowed button type'
                 self.form.screen.reload()
         else:
+            common.warning(_('Invalid form, correct red fields !'), _('Error !') )
             self.warn('misc-message', _('Invalid form, correct red fields !'), "red")
             self.form.screen.display()
 
@@ -157,6 +161,7 @@ class StateAwareWidget(object):
             result = True
             for condition in v:
                 result = result and tools.calc_condition(self,model,condition)
+                    
             if result:
                 if k=='invisible':
                     self.widget.hide()
@@ -164,6 +169,11 @@ class StateAwareWidget(object):
                     self.widget.set_sensitive(False)
                 else:
                     self.widget.set_sensitive(False and sa.get('readonly',False))
+            else:
+                if k=='readonly':
+                    self.widget.set_sensitive(True)
+                if k=='invisible':
+                    self.widget.show()        
 
 
 class _container(object):
@@ -480,34 +490,7 @@ class parser_form(widget.view.interface.parser_interface):
         return container.pop(), dict_widget, saw_list, on_write
 
     def translate(self, widget, event, model, name, src, widget_entry):
-        id = self.screen.current_model.id
-        if not id:
-            common.message(
-                    _('You need to save resource before adding translations!'),
-                    parent=self.window)
-            return False
-        id = self.screen.current_model.save(reload=False)
-        uid = rpc.session.uid
-
-        lang_ids = rpc.session.rpc_exec_auth('/object', 'execute', 'res.lang',
-                'search', [('translatable','=','1')])
-
-        if not lang_ids:
-            common.message(_('No other language available!'),
-                    parent=self.window)
-            return False
-        langs = rpc.session.rpc_exec_auth('/object', 'execute', 'res.lang',
-                'read', lang_ids, ['code', 'name'])
-
-        code = rpc.session.context.get('lang', 'en_US')
-
-        #change 'en' to false for context
-        def adapt_context(val):
-            if val == 'en_US':
-                return False
-            else:
-                return val
-
+        
         #widget accessor functions
         def value_get(widget):
             if type(widget) == type(gtk.Entry()):
@@ -550,6 +533,40 @@ class parser_form(widget.view.interface.parser_interface):
                 return sw, gtk.FILL | gtk.EXPAND
             else:
                 return None, False
+            
+        if not value_get(widget_entry):
+            common.message(
+                    _('Enter some text to the related field before adding translations!'),
+                    parent=self.window)
+            return False
+        
+        id = self.screen.current_model.id
+        if not id:
+            common.message(
+                    _('You need to save resource before adding translations!'),
+                    parent=self.window)
+            return False
+        id = self.screen.current_model.save(reload=False)
+        uid = rpc.session.uid
+
+        lang_ids = rpc.session.rpc_exec_auth('/object', 'execute', 'res.lang',
+                'search', [('translatable','=','1')])
+
+        if not lang_ids:
+            common.message(_('No other language available!'),
+                    parent=self.window)
+            return False
+        langs = rpc.session.rpc_exec_auth('/object', 'execute', 'res.lang',
+                'read', lang_ids, ['code', 'name'])
+
+        code = rpc.session.context.get('lang', 'en_US')
+
+        #change 'en' to false for context
+        def adapt_context(val):
+            if val == 'en_US':
+                return False
+            else:
+                return val
 
 
         win = gtk.Dialog(_('Add Translation'), self.window,
