@@ -278,7 +278,7 @@ class GenericDate(Char):
         if not value:
             return ''
         try:
-            date = DT.datetime.strptime(value, self.server_format)
+            date = DT.datetime.strptime(value[:10], self.server_format)
             return date.strftime(self.display_format)
         except:
             return ''
@@ -287,7 +287,7 @@ class GenericDate(Char):
         dt = self.renderer.date_get(self.renderer.editable)
         res = dt and dt.strftime(self.server_format)
         if res:
-            DT.datetime.strptime(res, self.server_format)
+            DT.datetime.strptime(res[:10], self.server_format)
         return res
 
 class Date(GenericDate):
@@ -302,7 +302,7 @@ class Datetime(GenericDate):
         value = model[self.field_name].get_client(model)
         if not value:
             return ''
-        date = DT.datetime.strptime(value, self.server_format)
+        date = DT.datetime.strptime(value[:19], self.server_format)
         
         if rpc.session.context.get('tz'):
             import pytz
@@ -315,7 +315,7 @@ class Datetime(GenericDate):
     def value_from_text(self, model, text):
         if not text:
             return False
-        date = DT.datetime.strptime(text, self.display_format)
+        date = DT.datetime.strptime(text[:19], self.display_format)
         if rpc.session.context.get('tz'):
             import pytz
             lzone = pytz.timezone(str(rpc.session.context['tz']))
@@ -339,7 +339,7 @@ class Float(Char):
 class FloatTime(Char):
     def get_textual_value(self, model):
         val = model[self.field_name].get_client(model)
-        t = '%02d:%02d' % (math.floor(abs(val)),round(abs(val)%1+0.01,2) * 60)
+        t = '%02d:%02d' % (math.floor(abs(val)),round(abs(val)%1+0.01,4) * 60)
         if val<0:
             t = '-'+t
         return t
@@ -347,7 +347,7 @@ class FloatTime(Char):
     def value_from_text(self, model, text):
         try:
             if text and ':' in text:
-                return round(int(text.split(':')[0]) + int(text.split(':')[1]) / 60.0,2)
+                return round(int(text.split(':')[0]) + int(text.split(':')[1]) / 60.0,4)
             else:
                 return locale.atof(text)
         except:
